@@ -62,9 +62,6 @@ GtkBuilder *go_gtk_builder_load_internal (char const *uifile,
 GtkBuilder *go_gtk_builder_load (char const *uifile,
 				char const *domain, GOCmdContext *gcc);
 #ifndef GOFFICE_DISABLE_DEPRECATED
-GOFFICE_DEPRECATED_FOR(go_gtk_builder_load_internal)
-GtkBuilder *go_gtk_builder_new_internal (char const *uifile,
-					 char const *domain, GOCmdContext *gcc);
 GOFFICE_DEPRECATED_FOR(go_gtk_builder_load)
 GtkBuilder *go_gtk_builder_new (char const *uifile,
 				char const *domain, GOCmdContext *gcc);
@@ -136,6 +133,11 @@ void 	   go_menu_position_below (GtkMenu *menu, gint *x, gint *y,
 
 GError	  *go_gtk_url_show (gchar const *url, GdkScreen *screen);
 
+GdkPixbuf *go_gtk_widget_render_icon_pixbuf (GtkWidget   *widget,
+					     const gchar *icon_name,
+					     GtkIconSize  size);
+
+
 G_END_DECLS
 
 #endif /* _GOFFICE_GTK_H_ */
